// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******
********************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
   global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example2"

// We can then refer to the syntax variable "filesave" by putting $ in front

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
   clear // Clear before means close any open data
   import excel "$filesave\GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)
                            
// Create formats: set of value labels for categorical variables;                            
   label define Fmarry    1 "1.Unmarried" 2 "2.Married"
   label define Fgender   1 "1.Man" 2 "2.Woman"          
   label define Fhappy    1 "1.Unhappy" 2 "2.Neither" 3 "3.Fairly Happy" /// 
                             4 "4.Very Happy" 5 "5.Completely Happy"  
   label define Ffriends  1 "1.Never" 2 "2.Once/Year" 3 "3. Several/Year" ///
                             4 "4.Once/Month" 5 "5.Several/Month"  ///
                             6 "6.Several/Week" 7 "7.Almost Daily"
   
// Label variables and apply value formats for variables used below
// label variable name    "name: Descriptive Variable Label"   
   label variable marry   "marry: 2-Category Marital Status"
   label variable gender  "gender: 2-Category Gender Identity"
   label variable happy   "happy: 5-Category Happy Rating"
   label variable friends "friends: 7-Category Time with Friends"
   label variable educ    "educ: Years of Education"
   label variable income  "income: Annual Income in 1000s"
   
// Apply value labels created above: name Format
   label values marry Fmarry 
   label values gender Fgender
   label values happy Fhappy
   label values friends Ffriends

// Example linear transformation: z-scoring 
// EGEN does more complicated transformations
   egen incomeZ = std(income)
   label variable income "income: Z-Scored Annual Income"

// Example nonlinear transformation: natural-log transform
   gen incomeLog = log(income)
   label variable incomeLog "incomeLog: Log Annual Income"   
   
// Now dataset is ready to use

// Save results to separate text file
   log using $filesave\Example2_STATA_Output.log, replace 

********************************************************************************
*******     BIVARIATE ASSOCIATIONS FOR QUANTITATIVE VARIABLES            *******
********************************************************************************

// Request descriptive statistics for quantitative variables
   display "Descriptive statistics for quantitative variables"
   summarize income incomeZ incomeLog educ
   
// MEAN gives SE of mean and level% CIs
   mean income incomeZ incomeLog educ, level(95)
   
// Request Pearson correlations and p-values
   display "Pearson correlations for quantitative variables"
   pwcorr income incomeZ incomeLog educ, sig obs
   
// To get CI using r-to-z, need to download and run a special module, ci2
   ssc install ci2
   
// CI2 to use Fisher r-to-z transform to get CI for Pearson correlation
   display "Fisher r-to-z transform to get CI for Pearson correlation"
   ci2 incomeLog educ, corr  // Need to list each pair of variables separately    
   
// Make scatterplot with regression lines to show predicted linear relations
   display "Scatterplot and regression line for x=income and y=incomeLog"
   graph twoway (lfit incomeLog income) (scatter incomeLog income)
   
   display "Scatterplot and regression line for x=educ and y=incomeLog"
   graph twoway (lfit incomeLog educ) (scatter incomeLog educ)

********************************************************************************
*******       BIVARIATE ASSOCIATIONS FOR ORDINAL VARIABLES               *******
********************************************************************************

// To get median, download and run a special module, univar
   ssc install univar
// Request median for quantitative or ordinal variables
   display "Median for quantitative and ordinal variables"
   univar income friends happy

// Request Spearman correlations and p-values
   display "Spearman correlations for rank-order quantitative and ordinal variables"
   spearman income friends happy, stats(rho obs p)
   
// CI2 to use Fisher r-to-z transform to get CI for Pearson correlation   
   display "Fisher r-to-z transform to get CI for Spearman correlation"
   ci2 income friends, corr spearman  // Need to list each pair of variables separately     
   
********************************************************************************
*******        BIVARIATE ASSOCIATIONS FOR BINARY VARIABLES               *******
********************************************************************************
   
// Request cross-tabulation of categorical variables with percentages
   display "Cross-tabulations for binary variables gender and marry"
   tabulate gender marry, cell

// Request x2 test of association with expected frequencies
   display "Chi-square tests for binary variables gender and marry"
   tab2 gender marry, chi2 expected
   
// Make STATA compute expected frequencies manually: Nrow*Ncol/Ntotal
   display "Expected Frequency for Man, Unmarried"
   display 363*397/734
   
// Request Pearson correlation, p-value, and CI
   display "Pearson correlation and CI for binary variables gender and marry"
   pwcorr gender marry, sig obs
   ci2 gender marry, corr 

////////////////////////////////////////////////////////////////////////////////
// Close log
   log close  
     
       
       



